ErrorKind

Enum ErrorKind 

#[non_exhaustive]
pub enum ErrorKind { Failed, InvalidTag { byte: u8, }, InvalidLength, Length { tag: Tag, }, Overflow, Overlength, TrailingData { decoded: Length, remaining: Length, }, Truncated, Underlength { expected: Length, actual: Length, }, UnexpectedTag { expected: Option<Tag>, actual: Tag, }, }
Error type.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Failed

Operation failed due to previous error



InvalidTag

Invalid tag

Fields

byte: u8

Raw byte value of the tag



InvalidLength

Length greater than u16::MAX



Length

Incorrect length for a given field

Fields

tag: Tag

Tag type of the value being decoded



Overflow

Integer overflow occurred (library bug!)



Overlength

Message is longer than SIMPLE-TLV’s limits support



TrailingData

Undecoded trailing data at end of message

Fields

decoded: Length

Length of the decoded data

remaining: Length

Total length of the remaining data left in the buffer



Truncated

Unexpected end-of-message/nested field when decoding



Underlength

Encoded message is shorter than the expected length (i.e. an Encodable impl on a particular type has a buggy encoded_length)

Fields

expected: Length

Expected length

actual: Length

Actual length



UnexpectedTag

Unexpected tag

Fields

expected: Option<Tag>

Tag the decoder was expecting (if there is a single such tag).

None if multiple tags are expected/allowed, but the actual tag does not match any of them.

actual: Tag

Actual tag encountered in the message

Implementations

Source

impl ErrorKind

pub fn at(self, position: Length) -> Error

Annotate an ErrorKind with context about where it occurred, returning an error.